@@ -218,6 +218,7 @@ class Sale(Workflow, ModelSQL, ModelView, TaxableMixin):
     @classmethod
     def __setup__(cls):
         super(Sale, cls).__setup__()
+        cls.create_date.select = True
         cls._order = [
             ('sale_date', 'DESC'),
             ('id', 'DESC'),
@@ -306,8 +307,6 @@ class Sale(Workflow, ModelSQL, ModelView, TaxableMixin):
         # Migration from 4.0: Drop not null on payment_term
         table.not_null_action('payment_term', 'remove')
 
-        # Add index on create_date
-        table.index_action('create_date', action='add')
 
     @classmethod
     def default_payment_term(cls):
@@ -1281,10 +1280,10 @@ class SaleLine(sequence_ordered(), ModelSQL, ModelView):
     def on_change_with_shipping_date(self, name=None):
         pool = Pool()
         Date = pool.get('ir.date')
-        if self.moves:
+        moves = [m for m in self.moves if m.state != 'cancel']
+        if moves:
             dates = filter(
-                None, (m.effective_date or m.planned_date for m in self.moves
-                    if m.state != 'cancel'))
+                None, (m.effective_date or m.planned_date for m in moves))
             return min(dates, default=None)
         if self.product and self.quantity is not None and self.quantity > 0:
             date = self.sale.sale_date if self.sale else None
@@ -1309,6 +1308,8 @@ class SaleLine(sequence_ordered(), ModelSQL, ModelView):
 
         invoice_line = InvoiceLine()
         invoice_line.type = self.type
+        invoice_line.currency = self.sale.currency
+        invoice_line.company = self.sale.company
         invoice_line.description = self.description
         invoice_line.note = self.note
         invoice_line.origin = self
